@@ -11,12 +11,15 @@ namespace waybar {
 
 class AModule : public IModule {
  public:
+  static constexpr const char *MODULE_CLASS = "module";
+
   virtual ~AModule();
   auto update() -> void override;
   virtual auto refresh(int) -> void{};
   operator Gtk::Widget &() override;
   auto doAction(const std::string &name) -> void override;
 
+  /// Emitting on this dispatcher triggers a update() call
   Glib::Dispatcher dp;
 
  protected:
@@ -34,13 +37,18 @@ class AModule : public IModule {
   const Json::Value &config_;
   Gtk::EventBox event_box_;
 
+  virtual void setCursor(Gdk::CursorType const c);
+
   virtual bool handleToggle(GdkEventButton *const &ev);
+  virtual bool handleMouseEnter(GdkEventCrossing *const &ev);
+  virtual bool handleMouseLeave(GdkEventCrossing *const &ev);
   virtual bool handleScroll(GdkEventScroll *);
   virtual bool handleRelease(GdkEventButton *const &ev);
 
  private:
   bool handleUserEvent(GdkEventButton *const &ev);
-
+  const bool isTooltip;
+  bool hasUserEvents_;
   std::vector<int> pid_;
   gdouble distance_scrolled_y_;
   gdouble distance_scrolled_x_;
