@@ -1,11 +1,9 @@
 #pragma once
 
-#include <functional>
 #include <list>
 #include <memory>
 #include <mutex>
 #include <string>
-#include <thread>
 #include <utility>
 
 #include "util/json.hpp"
@@ -22,19 +20,19 @@ class IPC {
  public:
   IPC() { startIPC(); }
 
-  void registerForIPC(const std::string&, EventHandler*);
-  void unregisterForIPC(EventHandler*);
+  void registerForIPC(const std::string& ev, EventHandler* ev_handler);
+  void unregisterForIPC(EventHandler* handler);
 
-  std::string getSocket1Reply(const std::string& rq);
+  static std::string getSocket1Reply(const std::string& rq);
   Json::Value getSocket1JsonReply(const std::string& rq);
 
  private:
   void startIPC();
   void parseIPC(const std::string&);
 
-  std::mutex callbackMutex;
+  std::mutex callbackMutex_;
   util::JsonParser parser_;
-  std::list<std::pair<std::string, EventHandler*>> callbacks;
+  std::list<std::pair<std::string, EventHandler*>> callbacks_;
 };
 
 inline std::unique_ptr<IPC> gIPC;
