@@ -66,12 +66,14 @@ class UPower : public AModule {
   Devices devices;
   std::mutex m_Mutex;
   UpClient *client;
-  UpDevice *displayDevice;
+  UpDevice *displayDevice = nullptr;
   guint login1_id;
   GDBusConnection *login1_connection;
   std::unique_ptr<UPowerTooltip> upower_tooltip;
   std::string lastStatus;
+  const char *lastWarningLevel = nullptr;
   bool showAltText;
+  bool showIcon = true;
   bool upowerRunning;
   guint upowerWatcher_id;
   std::string nativePath_;
