@@ -23,7 +23,7 @@ def signal_handler(sig, frame):
 
 
 class PlayerManager:
-    def __init__(self, selected_player=None):
+    def __init__(self, selected_player=None, excluded_player=[]):
         self.manager = Playerctl.PlayerManager()
         self.loop = GLib.MainLoop()
         self.manager.connect(
@@ -35,11 +35,14 @@ class PlayerManager:
         signal.signal(signal.SIGTERM, signal_handler)
         signal.signal(signal.SIGPIPE, signal.SIG_DFL)
         self.selected_player = selected_player
+        self.excluded_player = excluded_player.split(',') if excluded_player else []
 
         self.init_players()
 
     def init_players(self):
         for player in self.manager.props.player_names:
+            if player.name in self.excluded_player:
+                continue
             if self.selected_player is not None and self.selected_player != player.name:
                 logger.debug(f"{player.name} is not the filtered player, skipping it")
                 continue
@@ -133,6 +136,10 @@ class PlayerManager:
 
     def on_player_appeared(self, _, player):
         logger.info(f"Player has appeared: {player.name}")
+        if player.name in self.excluded_player:
+            logger.debug(
+                "New player appeared, but it's in exclude player list, skipping")
+            return
         if player is not None and (self.selected_player is None or player.name == self.selected_player):
             self.init_player(player)
         else:
@@ -149,6 +156,8 @@ def parse_arguments():
     # Increase verbosity with every occurrence of -v
     parser.add_argument("-v", "--verbose", action="count", default=0)
 
+    parser.add_argument("-x", "--exclude", "- Comma-separated list of excluded player")
+
     # Define for which player we"re listening
     parser.add_argument("--player")
 
@@ -174,7 +183,10 @@ def main():
     logger.info("Creating player manager")
     if arguments.player:
         logger.info(f"Filtering for player: {arguments.player}")
-    player = PlayerManager(arguments.player)
+    if arguments.exclude:
+        logger.info(f"Exclude player {arguments.exclude}")
+
+    player = PlayerManager(arguments.player, arguments.exclude)
     player.run()
 
 
