@@ -17,9 +17,9 @@ namespace waybar::modules::hyprland {
 Window::Window(const std::string& id, const Bar& bar, const Json::Value& config)
     : AAppIconLabel(config, "window", id, "{title}", 0, true), bar_(bar) {
   modulesReady = true;
-  separate_outputs = config["separate-outputs"].asBool();
+  separateOutputs_ = config["separate-outputs"].asBool();
 
-  if (!gIPC.get()) {
+  if (!gIPC) {
     gIPC = std::make_unique<IPC>();
   }
 
@@ -45,41 +45,47 @@ auto Window::update() -> void {
   // fix ampersands
   std::lock_guard<std::mutex> lg(mutex_);
 
-  std::string window_name = waybar::util::sanitize_string(workspace_.last_window_title);
-  std::string window_address = workspace_.last_window;
+  std::string windowName = waybar::util::sanitize_string(workspace_.last_window_title);
+  std::string windowAddress = workspace_.last_window;
 
-  window_data_.title = window_name;
+  windowData_.title = windowName;
 
   if (!format_.empty()) {
     label_.show();
     label_.set_markup(waybar::util::rewriteString(
-        fmt::format(fmt::runtime(format_), fmt::arg("title", window_name),
-                    fmt::arg("initialTitle", window_data_.initial_title),
-                    fmt::arg("class", window_data_.class_name),
-                    fmt::arg("initialClass", window_data_.initial_class_name)),
+        fmt::format(fmt::runtime(format_), fmt::arg("title", windowName),
+                    fmt::arg("initialTitle", windowData_.initial_title),
+                    fmt::arg("class", windowData_.class_name),
+                    fmt::arg("initialClass", windowData_.initial_class_name)),
         config_["rewrite"]));
   } else {
     label_.hide();
   }
 
+  if (focused_) {
+    image_.show();
+  } else {
+    image_.hide();
+  }
+
   setClass("empty", workspace_.windows == 0);
   setClass("solo", solo_);
-  setClass("floating", all_floating_);
+  setClass("floating", allFloating_);
   setClass("swallowing", swallowing_);
   setClass("fullscreen", fullscreen_);
 
-  if (!last_solo_class_.empty() && solo_class_ != last_solo_class_) {
-    if (bar_.window.get_style_context()->has_class(last_solo_class_)) {
-      bar_.window.get_style_context()->remove_class(last_solo_class_);
-      spdlog::trace("Removing solo class: {}", last_solo_class_);
+  if (!lastSoloClass_.empty() && soloClass_ != lastSoloClass_) {
+    if (bar_.window.get_style_context()->has_class(lastSoloClass_)) {
+      bar_.window.get_style_context()->remove_class(lastSoloClass_);
+      spdlog::trace("Removing solo class: {}", lastSoloClass_);
     }
   }
 
-  if (!solo_class_.empty() && solo_class_ != last_solo_class_) {
-    bar_.window.get_style_context()->add_class(solo_class_);
-    spdlog::trace("Adding solo class: {}", solo_class_);
+  if (!soloClass_.empty() && soloClass_ != lastSoloClass_) {
+    bar_.window.get_style_context()->add_class(soloClass_);
+    spdlog::trace("Adding solo class: {}", soloClass_);
   }
-  last_solo_class_ = solo_class_;
+  lastSoloClass_ = soloClass_;
 
   AAppIconLabel::update();
 }
@@ -113,8 +119,12 @@ auto Window::getActiveWorkspace(const std::string& monitorName) -> Workspace {
 }
 
 auto Window::Workspace::parse(const Json::Value& value) -> Window::Workspace {
-  return Workspace{value["id"].asInt(), value["windows"].asInt(), value["lastwindow"].asString(),
-                   value["lastwindowtitle"].asString()};
+  return Workspace{
+      value["id"].asInt(),
+      value["windows"].asInt(),
+      value["lastwindow"].asString(),
+      value["lastwindowtitle"].asString(),
+  };
 }
 
 auto Window::WindowData::parse(const Json::Value& value) -> Window::WindowData {
@@ -127,40 +137,45 @@ auto Window::WindowData::parse(const Json::Value& value) -> Window::WindowData {
 void Window::queryActiveWorkspace() {
   std::lock_guard<std::mutex> lg(mutex_);
 
-  if (separate_outputs) {
+  if (separateOutputs_) {
     workspace_ = getActiveWorkspace(this->bar_.output->name);
   } else {
     workspace_ = getActiveWorkspace();
   }
 
+  focused_ = true;
   if (workspace_.windows > 0) {
     const auto clients = gIPC->getSocket1JsonReply("clients");
     assert(clients.isArray());
-    auto active_window = std::find_if(clients.begin(), clients.end(), [&](Json::Value window) {
+    auto activeWindow = std::find_if(clients.begin(), clients.end(), [&](Json::Value window) {
       return window["address"] == workspace_.last_window;
     });
-    if (active_window == std::end(clients)) {
+
+    if (activeWindow == std::end(clients)) {
+      focused_ = false;
       return;
     }
 
-    window_data_ = WindowData::parse(*active_window);
-    updateAppIconName(window_data_.class_name, window_data_.initial_class_name);
-    std::vector<Json::Value> workspace_windows;
-    std::copy_if(clients.begin(), clients.end(), std::back_inserter(workspace_windows),
+    windowData_ = WindowData::parse(*activeWindow);
+    updateAppIconName(windowData_.class_name, windowData_.initial_class_name);
+    std::vector<Json::Value> workspaceWindows;
+    std::copy_if(clients.begin(), clients.end(), std::back_inserter(workspaceWindows),
                  [&](Json::Value window) {
                    return window["workspace"]["id"] == workspace_.id && window["mapped"].asBool();
                  });
-    swallowing_ = std::any_of(workspace_windows.begin(), workspace_windows.end(),
-                              [&](Json::Value window) { return !window["swallowing"].isNull(); });
-    std::vector<Json::Value> visible_windows;
-    std::copy_if(workspace_windows.begin(), workspace_windows.end(),
-                 std::back_inserter(visible_windows),
+    swallowing_ =
+        std::any_of(workspaceWindows.begin(), workspaceWindows.end(), [&](Json::Value window) {
+          return !window["swallowing"].isNull() && window["swallowing"].asString() != "0x0";
+        });
+    std::vector<Json::Value> visibleWindows;
+    std::copy_if(workspaceWindows.begin(), workspaceWindows.end(),
+                 std::back_inserter(visibleWindows),
                  [&](Json::Value window) { return !window["hidden"].asBool(); });
-    solo_ = 1 == std::count_if(visible_windows.begin(), visible_windows.end(),
+    solo_ = 1 == std::count_if(visibleWindows.begin(), visibleWindows.end(),
                                [&](Json::Value window) { return !window["floating"].asBool(); });
-    all_floating_ = std::all_of(visible_windows.begin(), visible_windows.end(),
-                                [&](Json::Value window) { return window["floating"].asBool(); });
-    fullscreen_ = window_data_.fullscreen;
+    allFloating_ = std::all_of(visibleWindows.begin(), visibleWindows.end(),
+                               [&](Json::Value window) { return window["floating"].asBool(); });
+    fullscreen_ = windowData_.fullscreen;
 
     // Fullscreen windows look like they are solo
     if (fullscreen_) {
@@ -168,23 +183,24 @@ void Window::queryActiveWorkspace() {
     }
 
     // Grouped windows have a tab bar and therefore don't look fullscreen or solo
-    if (window_data_.grouped) {
+    if (windowData_.grouped) {
       fullscreen_ = false;
       solo_ = false;
     }
 
     if (solo_) {
-      solo_class_ = window_data_.class_name;
+      soloClass_ = windowData_.class_name;
     } else {
-      solo_class_ = "";
+      soloClass_ = "";
     }
   } else {
-    window_data_ = WindowData{};
-    all_floating_ = false;
+    focused_ = false;
+    windowData_ = WindowData{};
+    allFloating_ = false;
     swallowing_ = false;
     fullscreen_ = false;
     solo_ = false;
-    solo_class_ = "";
+    soloClass_ = "";
   }
 }
 
